"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Log {
    _requestId = undefined;
    _tags = [];
    /**
     *
     * @param { requestId?: string, context?: Context } p requestId and context are optional, but if you want to capture the request ID (or use your own), you should pass them.  If you want to use AWS's requestId pass in the context, if you want to use your own requestId pass in 'requestId'
     */
    constructor({ requestId, context } = {}) {
        this._requestId = requestId ?? context?.awsRequestId ?? undefined;
        return this;
    }
    /**
     * retrieve the request ID (typically AWS's requestId or your own requestId)
     */
    get requestId() {
        return this._requestId;
    }
    /**
     * set the request ID (typically AWS's requestId or your own requestId)
     * @param {string} id - the request ID
     */
    set requestId(id) {
        this._requestId = id;
    }
    /**
     * retrieve the list of tags in the current log messages
     */
    get tags() {
        return this._tags;
    }
    /**
     * set the request id
     * @param id - the id of the request
     * @returns this - for chaining
     */
    setRequestId(id) {
        this._requestId = id;
        return this;
    }
    /**
     * add a tag message to the current log messages
     * @param tag - the tag to add to the current log messages
     * @returns this - for chaining
     */
    addTag(tag) {
        this._tags.push(tag);
        return this;
    }
    /**
     * removes the tag
     * @param tag - the tag to remove
     * @returns this - for chaining
     */
    removeTag(tag) {
        this._tags = this._tags.filter((t) => t !== tag);
        return this;
    }
    /**
     * cut the log message
     * @param level - the level of the message
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    cut(level, data) {
        return JSON.stringify({
            level,
            ...{ requestId: this.requestId },
            ...data,
            tags: this._tags.length > 0 ? this._tags : undefined
        });
    }
    /**
     * provides the actual console call to use for lambda
     * @param level - the level of the message
     * @returns this - for chaining
     */
    blade(level) {
        switch (level) {
            case 'info':
                return console.info;
            case 'debug':
                return console.debug;
            case 'warn':
                return console.warn;
            case 'error':
                return console.error;
        }
    }
    /**
     * log a message with data and tags for lambda
     * @param level - the level of the message
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    log(level, data) {
        this.blade(level)(this.cut(level, data));
        return this;
    }
    /**
     * log an INFO message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    info(data) {
        return this.log('info', data);
    }
    /**
     * log a DEBUG message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    debug(data) {
        return this.log('debug', data);
    }
    /**
     * log a WARN message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    warn(data) {
        return this.log('warn', data);
    }
    /**
     * log a ERROR message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    error(data) {
        return this.log('error', data);
    }
}
exports.default = Log;
