import { Context } from 'aws-lambda';
export interface LogConstruction {
    requestId?: string;
    context?: Context;
}
export declare type LogLevel = 'debug' | 'info' | 'warn' | 'error';
declare class Log<T = Record<string, unknown>> {
    private _requestId;
    private _tags;
    /**
     *
     * @param { requestId?: string, context?: Context } p requestId and context are optional, but if you want to capture the request ID (or use your own), you should pass them.  If you want to use AWS's requestId pass in the context, if you want to use your own requestId pass in 'requestId'
     */
    constructor({ requestId, context }?: LogConstruction);
    /**
     * retrieve the request ID (typically AWS's requestId or your own requestId)
     */
    get requestId(): string | undefined;
    /**
     * set the request ID (typically AWS's requestId or your own requestId)
     * @param {string} id - the request ID
     */
    set requestId(id: string | undefined);
    /**
     * retrieve the list of tags in the current log messages
     */
    get tags(): string[];
    /**
     * set the request id
     * @param id - the id of the request
     * @returns this - for chaining
     */
    setRequestId(id: string): this;
    /**
     * add a tag message to the current log messages
     * @param tag - the tag to add to the current log messages
     * @returns this - for chaining
     */
    addTag(tag: string): this;
    /**
     * removes the tag
     * @param tag - the tag to remove
     * @returns this - for chaining
     */
    removeTag(tag: string): this;
    /**
     * cut the log message
     * @param level - the level of the message
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    protected cut(level: LogLevel, data: T): string;
    /**
     * provides the actual console call to use for lambda
     * @param level - the level of the message
     * @returns this - for chaining
     */
    private blade;
    /**
     * log a message with data and tags for lambda
     * @param level - the level of the message
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    log(level: LogLevel, data: T): this;
    /**
     * log an INFO message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    info(data: T): this;
    /**
     * log a DEBUG message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    debug(data: T): this;
    /**
     * log a WARN message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    warn(data: T): this;
    /**
     * log a ERROR message with data and tags for lambda
     * @param data - the data to log (object defined by the user)(typescript available via generic)
     * @returns this - for chaining
     */
    error(data: T): this;
}
export default Log;
